﻿using MindFusion.Charting;
using MindFusion.Drawing;
using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.ComponentModel;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using Xamarin.Forms;

namespace BarChart
{
	// Learn more about making custom code visible in the Xamarin.Forms previewer
	// by visiting https://aka.ms/xamarinforms-previewer
	[DesignTimeVisible(false)]
	public partial class MainPage : ContentPage
	{
		public MainPage()
		{
			InitializeComponent();// create bar brushes

			firstBrush = new LinearGradientBrush(Color.FromRgb(0, 52, 102), Color.FromRgb(198, 217, 236), 0);
			secondBrush = new LinearGradientBrush(Color.FromRgb(156, 170, 198), Color.FromRgb(206, 213, 227), 0);
			thirdBrush = new LinearGradientBrush(Color.FromRgb(206, 0, 0), Color.FromRgb(255, 26, 26), 0);
			stroke = new SolidBrush(Color.FromRgb(0, 52, 102)); ;

			barChart.GridType = GridType.Horizontal;
			barChart.Theme.GridColor1 = Color.White;
			barChart.Theme.GridColor2 = Color.FromRgb(240, 240, 240);
			barChart.Theme.GridLineColor = Color.FromRgb(192, 192, 192);
			barChart.Theme.DataLabelsBrush = new SolidBrush(Color.FromRgb(100, 100, 100));
			barChart.Theme.AxisLabelsBrush = new SolidBrush(Color.FromRgb(100, 100, 100));
			barChart.Theme.AxisTitleBrush = new SolidBrush(Color.FromRgb(100, 100, 100));
			barChart.Theme.DataLabelsFontSize = 10;
			barChart.Theme.AxisLabelsFontSize = 11;
			barChart.Theme.AxisTitleFontSize = 14;
			barChart.Theme.LegendBackground = Brushes.White;
			barChart.Theme.LegendBorderStroke = new SolidBrush(Color.FromRgb(100, 100, 100));
			barChart.Theme.LegendTitleBrush = new SolidBrush(Color.FromRgb(100, 100, 100));
			barChart.Theme.AxisStroke = new SolidBrush(Color.FromRgb(100, 100, 100));


			barChart.BackgroundColor = Colors.White;
			barChart.ShowZoomWidgets = true;

			// create sample data series
			barChart.Series = new ObservableCollection<Series>
			{
				new BarSeries(
					new List<double> { 1,2,9,8,10,11,9,8,9,10,11,12 },
					labels, null
				)
				{ Title = "Series1" },

				new BarSeries(
					new List<double> { 2,3,7,8,10,12,14,16,18,20,22,24 },
					labels, null
				)
				{ Title = "Series2" },

				new BarSeries(
					new List<double> { 2,8,13,15,13,8,2,8,13,15,13,8 },
					labels, null
				)
				{ Title = "Series3" }
			};
			barChart.XAxis.MinValue = 5;
			barChart.XAxis.MaxValue = 7;

			barChart.XAxis.Interval = 1;
			barChart.YAxis.Origin = 5;

			// assign one brush per series
			barChart.Plot.SeriesStyle = new PerSeriesStyle()
			{
				Fills = new List<MindFusion.Drawing.Brush>()
				{
					firstBrush, secondBrush, thirdBrush
				},
				Strokes = new List<MindFusion.Drawing.Brush>()
				{
					stroke
				},
				StrokeThicknesses = new List<double>()
				{
					0.5
				}
			};

			// set up bar layout combo box
			cbxBarLayout.ItemsSource = new[] {
				BarLayout.Overlay,
				BarLayout.SideBySide,
				BarLayout.Stack };
			cbxBarLayout.SelectedItem = BarLayout.SideBySide;
		}

		void cbxBarLayout_ItemSelected(object sender, SelectedItemChangedEventArgs e)
		{
			barChart.BarLayout = (BarLayout)cbxBarLayout.SelectedItem;
		}

		void chbHorizontalBars_Toggled(object sender, ToggledEventArgs e)
		{
			barChart.HorizontalBars = !barChart.HorizontalBars;
			firstBrush.Angle += (angle * 90);
			secondBrush.Angle += (angle * 90);
			thirdBrush.Angle += (angle * 90);
			angle *= -1;
			if (barChart.HorizontalBars)
			{
				barChart.XAxis.Origin = 5;
				barChart.YAxis.Origin = null;
			}
			else
			{
				barChart.XAxis.Origin = null;
				barChart.YAxis.Origin = 5;
			}
			barChart.Invalidate();
		}

		LinearGradientBrush firstBrush;
		LinearGradientBrush secondBrush;
		LinearGradientBrush thirdBrush;
		SolidBrush stroke;

		int angle = 1;

		List<string> labels = new List<string>()
		{
			"one", "two", "three", "four", "five", "six",
			"seven", "eight", "nine", "ten", "eleven", "twelve"
		};
	}
}
