﻿using MindFusion.Charting;
using MindFusion.Drawing;
using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.IO;
using System.Linq;
using System.Reflection;
using System.Text;
using System.Threading.Tasks;
using System.Xml.Linq;
using Xamarin.Forms;

namespace XmlBinding
{
	// Learn more about making custom code visible in the Xamarin.Forms previewer
	// by visiting https://aka.ms/xamarinforms-previewer
	[DesignTimeVisible(false)]
	public partial class MainPage : ContentPage
	{
		public MainPage()
		{
			InitializeComponent();

            lineChart.BackgroundColor = Colors.White;
            lineChart.LineType = LineType.Curve;

            var xml = GetEmbeddedResourceString(Assembly.GetAssembly(typeof(MainPage)), "Data.xml");

            // load sample xml file
            var doc = XDocument.Parse(xml);

            var xdata = doc.Element("weather-observations").Element("product").Element("group").Elements("obs").Elements("d")
                           .Where(e => e.Attribute("t").Value == "tx").ToList();

            // create XML series bound to XPath expressions and add them to the chart;
            // alternatively, you could assign the XmlDocument to Chart.DataSource
            // and assign the XPath expressions to its various DataField* properties
            var series = new XmlSeries(xdata, null, null, null, null, null, null, null, null);
            series.Title = "maximum temperature";
            lineChart.Series.Add(series);

            xdata = doc.Element("weather-observations").Element("product").Element("group").Elements("obs").Elements("d")
                           .Where(e => e.Attribute("t").Value == "tn").ToList();

            series = new XmlSeries(xdata, null, null, null, null, null, null, null, null);
            series.Title = "minimum temperature";
            lineChart.Series.Add(series);

            // customize appearance
            lineChart.XAxis.Title = "Time";
            lineChart.YAxis.Title = "Degrees Celsius";

            lineChart.GridType = GridType.Horizontal;  

            lineChart.LegendHorizontalAlignment = MindFusion.Charting.Components.LayoutAlignment.Far;
            lineChart.LegendVerticalAlignment = MindFusion.Charting.Components.LayoutAlignment.Far;

            lineChart.Theme = new Theme();
            lineChart.Theme.CommonSeriesFills = lineChart.Theme.CommonSeriesStrokes = new List<Brush>
            {
                Brushes.Red,
                Brushes.Blue
            };

            lineChart.Theme.GridLineStyle = DashStyle.Dot;
            lineChart.Theme.GridColor1 = lineChart.Theme.GridColor2 = Colors.White;
            lineChart.Theme.GridLineColor = Color.FromRgb(192, 192, 192);
            lineChart.Theme.DataLabelsBrush = new SolidBrush(Color.FromRgb(100, 100, 100));
            lineChart.Theme.AxisLabelsBrush = new SolidBrush(Color.FromRgb(100, 100, 100));
            lineChart.Theme.AxisTitleBrush = new SolidBrush(Color.FromRgb(100, 100, 100));
            lineChart.Theme.AxisStroke = new SolidBrush(Color.FromRgb(100, 100, 100));
            lineChart.Theme.DataLabelsFontSize = 12;
            lineChart.Theme.AxisLabelsFontSize = 12;
            lineChart.Theme.AxisTitleFontSize = 14;
            lineChart.Theme.LegendBackground = new SolidBrush(Color.FromRgb(245, 245, 245));
            lineChart.Theme.LegendBorderStroke = new SolidBrush(Color.FromRgb(100, 100, 100));
            lineChart.Theme.LegendTitleBrush = new SolidBrush(Color.FromRgb(100, 100, 100));
        }

        static Stream GetEmbeddedResourceStream(Assembly assembly, string resourceFileName)
        {
            var resourceNames = assembly.GetManifestResourceNames();

            var resourcePaths = resourceNames
                .Where(x => x.EndsWith(resourceFileName, StringComparison.CurrentCultureIgnoreCase))
                .ToArray();

            if (!resourcePaths.Any())
            {
                throw new Exception(string.Format("Resource ending with {0} not found.", resourceFileName));
            }

            if (resourcePaths.Count() > 1)
            {
                throw new Exception(string.Format("Multiple resources ending with {0} found: {1}{2}", resourceFileName, Environment.NewLine, string.Join(Environment.NewLine, resourcePaths)));
            }

            return assembly.GetManifestResourceStream(resourcePaths.Single());
        }

        static string GetEmbeddedResourceString(Assembly assembly, string resourceFileName)
        {
            var stream = GetEmbeddedResourceStream(assembly, resourceFileName);

            using (var streamReader = new StreamReader(stream))
            {
                return streamReader.ReadToEnd();
            }
        }
    }
}